
import cadquery as cq

# Create the first cylinder with clarified height
cylinder1 = cq.Workplane("XY").circle(10).extrude(5)  # Main cylinder slightly taller

# Create the second cylinder, slightly less extruded than the first
cylinder2 = cq.Workplane("XY").circle(5).extrude(4.5)  # Inner cylinder slightly shorter

# Combine the two cylinders by cutting the second out of the first
combined_cylinders = cylinder1.cut(cylinder2)

# Positioning and cutting a small rectangle on the right side of the first cylinder
# Assuming 'right side' refers to a specific lateral section on the positive x-axis
# The workplane is offset 7 units to the right in X, then the rectangle is drawn and cut thru all
rectangle_cut = combined_cylinders.faces(">Z").workplane(centerOption="CenterOfMass").\
                transformed(offset=(7, 0, 0)).rect(2, 5).cutThruAll()

# Save the output in the correct file name as requested
rectangle_cut.val().exportStl("Refine_2.stl")
